<script setup>
import {ref, onMounted} from "vue";
import {
	driveInfModule
} from "@/views/moudle/driveInf/driveInf";
import EditDriveParams from "@/components/params/editDriveParams.vue";
const editVisible = ref(false);

const {
	page,
	pageSize,
	total,
	driveList,
	carName,
	getDriveList
} = driveInfModule();

/**
 * 查询汽车列表
 * @return {Promise<void>}
 */
const searchDriveList = async ()=>{
	let res = await getDriveList();
	driveList.value = res.result;
}

/**
 * 每页查询个数变更
 * @param value 每页查询个数
 */
const sizeChange = (value)=>{
	pageSize.value = value;
	searchDriveList();
}

/**
 * 当前页个数
 * @param value 当前页页码
 */
const currentChange = (value)=>{
	page.value = value;
	searchDriveList();
}

onMounted(()=>{
	searchDriveList();
});
</script>

<template>
	<div class="page-container">
		<div class="page-content">
			<div class="page-header">
				<div class="input-list">
					<div class="input-item">
<!--						<div class="input-wrapper">-->
<!--							<div class="input-label">车辆名称:</div>-->
<!--							<div class="input-content">-->
<!--								<el-select v-model="carName" filterable>-->
<!--									<el-option-->
<!--										v-for="(item, key) in carList" :key="'key'+key"-->
<!--										:value="item.key" :label="item.label"></el-option>-->
<!--								</el-select>-->
<!--							</div>-->
<!--						</div>-->
					</div>
					<div class="input-item">
						<el-button type="success" icon="Plus">添加</el-button>
						<el-button type="primary" icon="Search">查询</el-button>
					</div>
				</div>
			</div>
			<div class="page-content">
				<el-table :data="driveList" height="100%">
					<el-table-column min-width="120" align="center" prop="name" label="车辆名称" />
					<el-table-column min-width="120" align="center" prop="boxSn" label="车辆编码"></el-table-column>
					<el-table-column align="center" prop="online" label="车辆状态">
						<template #default="{row}">
							<el-tag v-if="row.online" type="success">在线</el-tag>
							<el-tag v-else type="danger">离线</el-tag>
						</template>
					</el-table-column>
					<el-table-column min-width="170" align="center" prop="createTime1" label="创建日期"></el-table-column>
					<el-table-column min-width="170" align="center" prop="onlineTime1" label="在线时间"></el-table-column>
					<el-table-column min-width="170" align="center" prop="updateTime1" label="数据更新日期"></el-table-column>
					<el-table-column align="center" fixed="right" label="操作" width="120">
						<template #default>
							<el-button link type="primary" size="small" @click="editVisible = true">编辑</el-button>
							<el-button link type="primary" size="small">删除</el-button>
						</template>
					</el-table-column>
				</el-table>
			</div>
			<div class="page-footer">
				<div class="el-pagination-container">
					<el-pagination
						background
						layout="total, sizes, prev, pager, next, jumper"
						@size-change="sizeChange"
						@current-change="currentChange"
						:total="total"></el-pagination>
				</div>
			</div>
		</div>
	</div>
	<el-dialog
		v-model="editVisible"
		title="车辆信息编辑"
		width="auto"
		draggable
		destroy-on-close
		align-center>
		<edit-drive-params v-model:visible="editVisible"></edit-drive-params>
	</el-dialog>
</template>

<style scoped lang="less">
.page-container {
	height: 100%;
	padding: 12px;
	.page-content {
		display: flex;
		height: 100%;
		border-radius: 4px;
		box-shadow: 0 0 12px rgba(0, 0, 0, .16);
		flex-direction: column;
		.page-header {
			padding: 8px;
		}
		.page-content {
			flex: 1;
			overflow-y: auto;
		}
		.page-footer {
			padding: 8px 0;
			text-align: center;
			.el-pagination-container {
				display: inline-block;
			}
		}
	}
}

.input-list {
	.input-item {
		display: inline-block;
		margin-left: 8px;
	}
}
.input-wrapper {
	display: flex;
	.input-content {
		width: 160px;
	}
	.input-label {
		font-size: 14px;
		line-height: 40px;
		vertical-align: bottom;
		margin-right: 8px;
	}
}
</style>
